@@ -25,7 +25,7 @@ impl layeredconf::LayeredConfLayer for TestLayer {
     }
 }
 impl TestLayer {
-    fn empty(&self) -> bool {
+    pub fn empty(&self) -> bool {
         let mut empty = vec![];
         empty.push(self.boolean.is_none());
         empty.push(self.integer.is_none());
